@@ -17,6 +17,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from __future__ import annotations
+
 from dataclasses import dataclass
 from typing import Dict, List, Optional, Any
 
@@ -91,11 +92,15 @@ class ExecutionTaskOutput(_BaseDataObject):
 @dataclass(frozen=True)
 class ExecutionTaskOptions(_BaseDataObject):
     execution_details: bool
+    timeout_seconds: Optional[int] = None
+    metadata: Optional[Dict[str, str]] = None
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> ExecutionTaskOptions:
         return cls(
             execution_details=data['execution_details'],
+            timeout_seconds=data.get('timeout_seconds', None),
+            metadata=data.get('metadata', None)
         )
 
 
